var __extends = this.__extends || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    __.prototype = b.prototype;
    d.prototype = new __();
};
var Toffee;
(function (Toffee) {
    var Background = (function (_super) {
        __extends(Background, _super);
        function Background(game) {
            _super.call(this, game, 0, 0, 'tile');
            this.pressed = false;
            this.inputEnabled = true;
            this.scale.setTo(Toffee.Data.getWidth(), Toffee.Data.getHeight());
            this.events.onInputDown.add(this.onDown, this);
            this.events.onInputUp.add(this.onUp, this);
            game.add.existing(this);
        }
        Background.prototype.onDown = function () {
            this.shape.pressed = true;
            this.mold.pressed = true;
        };
        Background.prototype.onUp = function () {
            this.shape.pressed = false;
            this.mold.pressed = false;
        };
        return Background;
    })(Phaser.Sprite);
    Toffee.Background = Background;
})(Toffee || (Toffee = {}));
var Toffee;
(function (Toffee) {
    var Boot = (function (_super) {
        __extends(Boot, _super);
        function Boot() {
            _super.apply(this, arguments);
        }
        Boot.prototype.preload = function () {
            this.stage.backgroundColor = 0xdddddd;
            // Loader assets
        };
        Boot.prototype.create = function () {
            // How many max fingers into the making
            this.input.maxPointers = 1;
            // Run game even if not focus
            this.stage.disableVisibilityChange = true;
            this.game.state.start('Loader');
        };
        return Boot;
    })(Phaser.State);
    Toffee.Boot = Boot;
})(Toffee || (Toffee = {}));
var Toffee;
(function (Toffee) {
    var Entity = (function (_super) {
        __extends(Entity, _super);
        function Entity(game) {
            _super.call(this, game);
            // Check if background is pressed
            this.pressed = false;
            game.add.existing(this);
        }
        Entity.prototype.forEach = function (callback, context) {
            var args = [];
            for (var _i = 2; _i < arguments.length; _i++) {
                args[_i - 2] = arguments[_i];
            }
            for (var i = 0; i < this.grid.length; ++i) {
                for (var j = 0; j < this.grid.length; ++j) {
                    if (this.grid[i][j]) {
                        if (args.length > 0) {
                            var tmp = args.slice();
                            tmp.unshift(this.grid[i][j]);
                            callback.apply(context, tmp);
                        }
                        else {
                            callback.call(context, this.grid[i][j]);
                        }
                    }
                }
            }
        };
        // Color the entity !
        Entity.prototype.setColor = function (color) {
            this.forEach(function (child) {
                child.tint = color;
            }, this);
        };
        // Check for isolate tile
        Entity.prototype.clean = function () {
            // TODO
        };
        Entity.prototype.empty = function () {
            var _this = this;
            this.forEach(function (child) {
                _this.kill(child);
            }, this);
        };
        Entity.prototype.kill = function (tile) {
            delete this.grid[tile.gridX][tile.gridY];
            tile.destroy();
            this.clean();
        };
        Entity.prototype.snap = function () {
            var a = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                a[_i - 0] = arguments[_i];
            }
            return null;
        };
        Entity.prototype.follow = function () {
            var a = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                a[_i - 0] = arguments[_i];
            }
            return null;
        };
        return Entity;
    })(Phaser.Group);
    Toffee.Entity = Entity;
})(Toffee || (Toffee = {}));
/// <reference path="Entity" />
var Toffee;
(function (Toffee) {
    var Border = (function (_super) {
        __extends(Border, _super);
        function Border(game) {
            _super.call(this, game);
            this.grid = new Array(Toffee.Data.half);
            for (var i = 0; i < Toffee.Data.half; ++i) {
                this.grid[i] = new Array(1);
            }
            for (var i = 0; i < Toffee.Data.half; ++i) {
                this.grid[i][0] = new Toffee.Core(this.game, 0, i, this);
            }
            this.setColor(0xdddddd);
            this.forEach(function (child) {
                child.x += (Toffee.Data.half) * Toffee.Data.size;
            }, this);
        }
        return Border;
    })(Toffee.Entity);
    Toffee.Border = Border;
})(Toffee || (Toffee = {}));
var Toffee;
(function (Toffee) {
    var Tile = (function (_super) {
        __extends(Tile, _super);
        function Tile(game, x, y, entity) {
            _super.call(this, game, 0, 0, 'tile', 0);
            this.entity = entity;
            this.gridX = x;
            this.gridY = y;
            // Scale in pixel
            this.position.setTo(x * Toffee.Data.size, y * Toffee.Data.size);
            this.scale.setTo(Toffee.Data.size);
            this.tint = 0x00c0fc;
            // Hover
            this.inputEnabled = true;
            this.events.onInputOver.add(this.over, this);
            //this.events.onInputOut.add(out, this)
            game.add.existing(this);
        }
        Tile.prototype.over = function () {
            if (this.entity.pressed) {
                this.entity.kill(this);
            }
        };
        return Tile;
    })(Phaser.Sprite);
    Toffee.Tile = Tile;
})(Toffee || (Toffee = {}));
/// <reference path="Tile" />
var Toffee;
(function (Toffee) {
    var Movable = (function (_super) {
        __extends(Movable, _super);
        function Movable(game, x, y, entity) {
            _super.call(this, game, x, y, entity);
            // Drag & Drop
            this.input.enableDrag();
            this.events.onDragStart.add(this.startSnapDrag, this);
            this.events.onDragStop.add(this.stopSnapDrag, this);
            this.input.enableSnap(Toffee.Data.size, Toffee.Data.size, false, true);
        }
        Movable.prototype.startSnapDrag = function () {
            this.entity.snap();
            this.entity.onCatch();
        };
        Movable.prototype.stopSnapDrag = function () {
            this.updateDist();
            this.entity.follow(this);
            this.entity.onRelease();
        };
        Movable.prototype.snapPosition = function () {
            this.snapX = this.x;
            this.snapY = this.y;
        };
        Movable.prototype.updateDist = function () {
            this.distX = this.x - this.snapX;
            this.distY = this.y - this.snapY;
        };
        Movable.prototype.update = function () {
            if (this.input.isDragged) {
                this.updateDist();
                this.entity.follow(this);
            }
        };
        return Movable;
    })(Toffee.Tile);
    Toffee.Movable = Movable;
})(Toffee || (Toffee = {}));
/// <reference path="Movable" />
var Toffee;
(function (Toffee) {
    var Core = (function (_super) {
        __extends(Core, _super);
        function Core(game, x, y, shape) {
            _super.call(this, game, x, y, shape);
            //this.tint = 0x0000ff
        }
        // Can't destroy core tile
        Core.prototype.over = function () {
            return null;
        };
        return Core;
    })(Toffee.Movable);
    Toffee.Core = Core;
})(Toffee || (Toffee = {}));
var Toffee;
(function (Toffee) {
    var Data = (function () {
        function Data() {
        }
        // Game's min size
        Data.getWidth = function () {
            return (Data.half * 2 + Data.border) * Data.size;
        };
        Data.getHeight = function () {
            return Data.half * Data.size;
        };
        Data.parseDataShapes = function (file) {
            var lines = file.split("\n");
            var current = -1;
            for (var i = 0; i < lines.length; ++i) {
                var line = lines[i];
                // Ignore commentary
                if (line[0] == "#") {
                    continue;
                }
                // Empty line
                if (line.length == 0) {
                    if (Data.shapes[current] && Data.shapes[current].length != Data.accumulation) {
                        console.log("Warning shape number " + current + 1 + "\n");
                    }
                    ++current;
                    Data.shapes[current] = [];
                    continue;
                }
                // Warning if not good size
                if (line.length != Data.accumulation) {
                    console.log("Warning at line " + i + "\n");
                }
                // File line shape with data
                var tmp = [];
                for (var j = 0; j < line.length; ++j) {
                    tmp.push(parseInt(line[j]));
                }
                Data.shapes[current].push(tmp);
            }
            Data.base = Data.shapes.shift();
            Data.shapes.pop(); // Remove last black ending
        };
        // Text
        Data.wailings = [
            "Please stop...",
            "It hurts...",
            "Aïe...",
            "Ouch...",
            "Please no...",
            "Don't cut me...",
            "You hurt me...",
            "No..."
        ];
        Data.clue = [
            "I love this @mold ! It's so about the @norm !",
            "Luckily, our @mold is @indestructible !",
            "Can you @guess if we didn't have this @mold ?"
        ];
        Data.cool = [
            "Nice one",
            "Sharp as well",
            "Perfect",
            "Fit really well",
            "Like everyone !",
        ];
        // Message style
        Data.regular_style = { font: "24px 'Open Sans'", fill: "#ffffff", align: "left", fontWeight: "bold" };
        Data.blue_style = { font: "24px 'Open Sans'", fill: "#00c0fc", align: "left", fontWeight: "bold" };
        Data.clue_style = { font: "24px 'Open Sans'", fill: "#ffffff", align: "left", fontWeight: "bold", bounce: true };
        Data.eurk_style = { font: "28px 'Amatic SC'", fill: "#ffffff", align: "left", minusY: true };
        Data.wailing_style = { font: "18px Calligraffitti", fill: "#252525", align: "left" };
        Data.thanks_style = { font: "32px Calligraffitti", fill: "#ffffff", align: "left" };
        Data.cool_style = { font: "32px 'Open Sans'", fill: "#ffffff", align: "center" };
        Data.nooo_style = { font: "24px 'Open Sans'", fill: "#ffffff", align: "center", anim: true };
        // Color
        Data.binaire = [0x00c0fc, 0xfc0080];
        Data.rainbow = [0x00fc5f, 0xfc9400, 0xb513af, 0xbf0531, 0xead704, 0x05afa1];
        // Tile width / height
        Data.size = 32;
        // Margin from surface shape
        Data.margin = 3;
        // Number of breakable tile
        Data.coat = 2;
        // Number of unbreakble tile
        Data.core = 2;
        // Number of unbreakle mold tile
        Data.border = 2;
        // Number of splited tile
        Data.split = 1;
        // Total shape size
        Data.accumulation = Data.margin * 2 + Data.coat * 2 + Data.core;
        // Half part
        Data.half = Data.accumulation + Data.border * 2;
        // Mold Dist
        Data.moldX = 0;
        // Shape Dist
        Data.shapeX = (Data.half + Data.border + Data.split) * Data.size;
        Data.shapeY = Data.border * Data.size;
        // All shapes
        Data.base = [];
        Data.shapes = [];
        return Data;
    })();
    Toffee.Data = Data;
})(Toffee || (Toffee = {}));
var Toffee;
(function (Toffee) {
    var Game = (function (_super) {
        __extends(Game, _super);
        function Game() {
            // width, height, renderer, parent, state, transparent, antialias, physicsConfig
            _super.call(this, Toffee.Data.getWidth(), Toffee.Data.getHeight(), Phaser.AUTO, 'game', null, false, false, null);
            this.state.add('Boot', Toffee.Boot, false);
            this.state.add('Loader', Toffee.Loader, false);
            this.state.add('Play', Toffee.Play, false);
            this.state.start('Boot');
        }
        return Game;
    })(Phaser.Game);
    Toffee.Game = Game;
})(Toffee || (Toffee = {}));
var Toffee;
(function (Toffee) {
    var Loader = (function (_super) {
        __extends(Loader, _super);
        function Loader() {
            _super.apply(this, arguments);
        }
        Loader.prototype.preload = function () {
            // Game's assets
            this.load.image('tile', 'assets/tile.png');
            this.load.image('pointer', 'assets/pointer.png');
            this.load.text('shapes', 'assets/shapes.txt');
        };
        Loader.prototype.create = function () {
            Toffee.Data.parseDataShapes(this.game.cache.getText('shapes'));
            // Create dump text
            var dd = [Toffee.Data.regular_style, Toffee.Data.eurk_style, Toffee.Data.wailing_style];
            for (var i in dd) {
                var txt = new Phaser.Text(this.game, 0, 0, "dd", dd[i]);
                txt.destroy();
            }
            this.game.time.events.add(Phaser.Timer.SECOND, this.nextState, this);
        };
        Loader.prototype.nextState = function () {
            this.game.state.start('Play');
        };
        return Loader;
    })(Phaser.State);
    Toffee.Loader = Loader;
})(Toffee || (Toffee = {}));
window.onload = function () {
    var game = new Toffee.Game();
};
/// <reference path="Entity" />
var Toffee;
(function (Toffee) {
    var Mold = (function (_super) {
        __extends(Mold, _super);
        function Mold(game) {
            _super.call(this, game);
            this.counter = 0;
        }
        Mold.prototype.populate = function () {
            this.grid = new Array(Toffee.Data.half);
            for (var i = 0; i < Toffee.Data.half; ++i) {
                this.grid[i] = new Array(Toffee.Data.half);
            }
            for (var i = 0; i < Toffee.Data.half; ++i) {
                for (var j = 0; j < Toffee.Data.half; ++j) {
                    this.grid[i][j] = new Toffee.Tile(this.game, i, j, this);
                }
            }
            for (var i = Toffee.Data.border + Toffee.Data.margin; i < Toffee.Data.border + Toffee.Data.margin + Toffee.Data.coat * 2 + Toffee.Data.core; ++i) {
                for (var j = Toffee.Data.border + Toffee.Data.margin; j < Toffee.Data.border + Toffee.Data.margin + Toffee.Data.coat * 2 + Toffee.Data.core; ++j) {
                    this.kill(this.grid[i][j]);
                }
            }
            // Put corner left not breable
            this.kill(this.grid[0][0]);
            this.grid[0][0] = new Toffee.Core(this.game, 0, 0, this);
        };
        Mold.prototype.kill = function (tile) {
            _super.prototype.kill.call(this, tile);
            if (this.pressed) {
                this.current.breakingMold(++this.counter);
            }
        };
        // Check if there is void at the coordonate
        Mold.prototype.isEmpty = function (x, y) {
            if (Toffee.Data.border <= x && x <= Toffee.Data.border + Toffee.Data.accumulation && Toffee.Data.border <= y && y <= Toffee.Data.border + Toffee.Data.accumulation) {
                if (!this.grid[x][y]) {
                    return true;
                }
            }
            return false;
        };
        return Mold;
    })(Toffee.Entity);
    Toffee.Mold = Mold;
})(Toffee || (Toffee = {}));
var Toffee;
(function (Toffee) {
    var Play = (function (_super) {
        __extends(Play, _super);
        function Play() {
            _super.apply(this, arguments);
            this.tutoNumber = 0;
            this.breaked = false;
            this.counter = 0;
        }
        Play.prototype.create = function () {
            var background = new Toffee.Background(this.game);
            var border = new Toffee.Border(this.game);
            this.mold = new Toffee.Mold(this.game);
            this.shape = new Toffee.Shape(this.game);
            this.speech = new Toffee.Speech(this.game);
            this.tuto = new Toffee.Tuto(this.game);
            this.wailings = new Toffee.Wailings(this.game);
            background.shape = this.shape;
            background.mold = this.mold;
            this.shape.mold = this.mold;
            this.shape.current = this;
            this.mold.current = this;
            this.firstWave();
        };
        Play.prototype.firstWave = function () {
            this.mold.populate();
            this.shape.populate(Toffee.Data.shapes[0]);
            this.shape.bin = Toffee.Data.binaire[0];
            this.mold.setColor(this.shape.bin);
            this.mold.rainbow = this.shape.rainbow;
            this.speech.write("First, drag it to the mold.");
            this.tuto.dragIt();
            // Bring to top
            this.game.world.bringToTop(this.speech);
            this.game.world.bringToTop(this.tuto);
        };
        Play.prototype.newWave = function () {
            // New shape
            this.shape.empty();
            //this.mold.empty()
            //this.mold.populate()
            this.shape.populate(this.game.rnd.pick(Toffee.Data.shapes));
            ++this.counter;
            this.game.world.bringToTop(this.speech);
        };
        Play.prototype.breakingMold = function (nb) {
            this.closeTuto();
            this.breaked = true;
            if (nb == 1) {
                this.speech.write("%WATCH %OUT %! Don't break the mold again !");
            }
            else if (nb == 4) {
                this.speech.write("%Why did you do that ! %What about the norm ! %Stop %it %!");
            }
            else if (nb > 8) {
                this.speech.write("%STOP %! %STOP %NOW %! %LEAVE %IT %!");
            }
            else if (nb > 12) {
                this.speech.write("%STOP %! Seriously ! You %can't do that %!");
            }
        };
        Play.prototype.closeTuto = function () {
            this.tutoNumber = 500;
            this.tuto.stopIt();
        };
        Play.prototype.cutted = function (percent) {
            if (this.tutoNumber == 2) {
                if (percent == 0) {
                    this.speech.write("Great ! Put ùhim into the mold.");
                }
            }
            else if (this.tutoNumber >= 2) {
                if (0.4 <= percent && percent <= 0.6) {
                    this.wailings.newOne();
                }
            }
        };
        Play.prototype.catched = function () {
            if (this.tutoNumber == 2) {
            }
            if (this.breaked) {
                this.speech.write("%NO ! Don't put _that inside !");
            }
        };
        Play.prototype.notFitting = function () {
            if (this.tutoNumber == 0) {
                ++this.tutoNumber;
                this.speech.write("See, _it doesn't fit. Drag it back were it was.");
                this.tuto.dragBack();
            }
            else if (this.tutoNumber == 1) {
                ++this.tutoNumber;
                this.speech.write("Now, cut the excedant !");
                this.tuto.stopIt();
            }
        };
        Play.prototype.fitting = function () {
            if (this.shape.first_diff == this.shape.delta) {
                var trans = new Toffee.Trans(this.game, this, this.shape.rainbow, true);
                return;
            }
            else if (this.tutoNumber == 2) {
                ++this.tutoNumber;
            }
            var old = this.shape.bin;
            this.newWave();
            this.shape.forEach(function (child) {
                child.alpha = 0;
            }, this);
            var trans = new Toffee.Trans(this.game, this, old);
        };
        Play.prototype.appear = function () {
            this.shape.forEach(function (child) {
                child.alpha = 1;
            }, this);
            this.mold.setColor(this.shape.bin);
            this.mold.rainbow = this.shape.rainbow;
            if (this.tutoNumber == 3) {
                ++this.tutoNumber;
                this.speech.write("ùHe's fitting perfectly ! Let's do it with another.");
                this.speech.autoClose();
            }
            if (this.counter > 3) {
                this.speech.write(this.game.rnd.pick(Toffee.Data.clue));
                this.speech.autoClose();
            }
        };
        return Play;
    })(Phaser.State);
    Toffee.Play = Play;
})(Toffee || (Toffee = {}));
/// <reference path="Entity" />
var Toffee;
(function (Toffee) {
    var Shape = (function (_super) {
        __extends(Shape, _super);
        function Shape(game) {
            _super.call(this, game);
            this.fit = false;
        }
        // Populate
        Shape.prototype.populate = function (shape) {
            this.grid = new Array(Toffee.Data.accumulation);
            for (var i = 0; i < Toffee.Data.accumulation; ++i) {
                this.grid[i] = new Array(Toffee.Data.accumulation);
            }
            for (var x = 0; x < shape.length; ++x) {
                for (var y = 0; y < shape.length; ++y) {
                    switch (shape[x][y]) {
                        case 1:
                            this.grid[y][x] = new Toffee.Movable(this.game, y, x, this);
                            break;
                        case 2:
                            this.grid[y][x] = new Toffee.Core(this.game, y, x, this);
                            break;
                    }
                }
            }
            //Move it to the left half
            this.forEach(function (child) {
                child.x += Toffee.Data.shapeX;
                child.y += Toffee.Data.shapeY;
            }, this);
            // how many diff
            this.diff();
            this.first_diff = this.delta;
            this.bin = this.game.rnd.pick(Toffee.Data.binaire);
            this.rainbow = this.game.rnd.pick(Toffee.Data.rainbow);
            this.setColor(this.rainbow);
        };
        Shape.prototype.onCatch = function () {
            this.current.catched();
        };
        // Shape realised
        Shape.prototype.onRelease = function () {
            if (this.fitting()) {
                this.current.fitting();
            }
            else {
                this.current.notFitting();
            }
        };
        Shape.prototype.diff = function () {
            var diff = 0;
            for (var y = 0; y < this.grid.length; ++y) {
                for (var x = 0; x < this.grid.length; ++x) {
                    if (Toffee.Data.base[x][y] == 0 && this.grid[x][y] != null) {
                        ++diff;
                    }
                }
            }
            this.delta = diff;
            //return diff
        };
        Shape.prototype.kill = function (tile) {
            _super.prototype.kill.call(this, tile);
            this.diff();
            this.setColor(Phaser.Color.interpolateColor(this.bin, this.rainbow, this.first_diff, this.delta, 1));
            this.current.cutted(this.delta / this.first_diff);
        };
        // Return if shape fit in mold
        Shape.prototype.fitting = function () {
            var _this = this;
            var origin = this.mold.grid[0][0].position;
            var center = this.grid[Toffee.Data.margin + Toffee.Data.coat][Toffee.Data.margin + Toffee.Data.coat];
            var dist = { x: center.x - origin.x, y: center.y - origin.y };
            dist.x /= Toffee.Data.size;
            dist.y /= Toffee.Data.size;
            this.fit = true;
            this.forEach(function (child, d) {
                var relative = { x: d.x + (child.gridX - Toffee.Data.margin - Toffee.Data.coat), y: d.y + (child.gridY - Toffee.Data.margin - Toffee.Data.coat) };
                if (!_this.mold.isEmpty(relative.x, relative.y)) {
                    _this.fit = false;
                }
            }, this, dist);
            return this.fit;
        };
        Shape.prototype.snap = function () {
            this.forEach(function (child) {
                child.snapPosition();
            }, this);
        };
        Shape.prototype.follow = function (tile) {
            this.forEach(function (child, dragged) {
                // Get other than clicked one
                if (child != dragged) {
                    child.x = child.snapX + dragged.distX;
                    child.y = child.snapY + dragged.distY;
                }
            }, this, tile);
        };
        return Shape;
    })(Toffee.Entity);
    Toffee.Shape = Shape;
})(Toffee || (Toffee = {}));
var Toffee;
(function (Toffee) {
    var Speech = (function (_super) {
        __extends(Speech, _super);
        function Speech(game) {
            _super.call(this, game, 0, 0, null);
            this.bubble = this.game.add.graphics(0, 0);
            this.bubble.beginFill(0x000000, 0.5);
            this.bubble.drawRect(0, 0, 600, 96);
            this.messages = [];
            var t = this.game.add.text(0, 0, "Test", Toffee.Data.regular_style);
            this.messages.push(t);
            this.addChild(this.bubble);
            this.addChild(t);
            this.anchor.setTo(0.5, 0);
            this.x = this.game.world.centerX - this.bubble.width / 2;
            this.y = 0;
            this.game.add.existing(this);
        }
        Speech.prototype.clear = function () {
            for (var i in this.messages) {
                this.removeChild(this.messages[i]);
                this.messages[i].destroy();
            }
        };
        Speech.prototype.write = function (message) {
            this.game.add.tween(this).to({ alpha: 1 }, 200).start();
            this.clear();
            var parsed = message.split(' ');
            // Write text
            var x = 16;
            var y = 0;
            for (var j in parsed) {
                // Create a tempory text
                var txt = parsed[j];
                var style = Toffee.Data.regular_style;
                if (txt[0] == '_') {
                    txt = txt.substr(1);
                    style = Toffee.Data.eurk_style;
                }
                else if (txt[0] == '%') {
                    txt = txt.substr(1);
                    style = Toffee.Data.nooo_style;
                }
                else if (txt[0] == 'ù') {
                    txt = txt.substr(1);
                    style = Toffee.Data.blue_style;
                }
                else if (txt[0] == '@') {
                    txt = txt.substr(1);
                    style = Toffee.Data.clue_style;
                }
                var t = this.game.add.text(0, 0, txt, style);
                // Check where to put it
                if (x + t.width > 584) {
                    if (y == 0) {
                        y = 42;
                        x = 16;
                    }
                    else {
                    }
                }
                // Postionne it where it belong
                t.position.setTo(x, y + 10 + (style.minusY ? -4 : 0));
                if (style.anim) {
                    var ax = t.x;
                    var ay = t.y;
                    this.game.add.tween(t).to({ x: ax + 2 }, 10).to({ y: ay + 2 }, 10).to({ x: ax }, 10).to({ y: ay }, 10).loop().start();
                }
                if (style.bounce) {
                    t.angle = -5;
                    this.game.add.tween(t).to({ angle: 5 }, 900).to({ angle: -5 }, 900).loop().start();
                }
                this.addChild(t);
                this.messages.push(t);
                // Add a space after
                x += t.width + 12;
            }
        };
        Speech.prototype.autoClose = function () {
            function fadeOut() {
                var _this = this;
                var tween = this.game.add.tween(this);
                tween.to({ alpha: 0 }, 200);
                tween.onComplete.add(function () {
                    _this.clear();
                }, this);
                tween.start();
            }
            this.game.time.events.add(Phaser.Timer.SECOND * 4, fadeOut, this);
        };
        return Speech;
    })(Phaser.Sprite);
    Toffee.Speech = Speech;
})(Toffee || (Toffee = {}));
var Toffee;
(function (Toffee) {
    var Trans = (function (_super) {
        __extends(Trans, _super);
        function Trans(game, play, color, done) {
            _super.call(this, game, 0, 0, null);
            this.playMe = play;
            // Create background
            this.rect = this.game.add.graphics(0, 0);
            this.rect.beginFill(color);
            this.rect.drawRect(0, 0, Toffee.Data.getWidth(), Toffee.Data.getHeight());
            if (done == true) {
                this.text = this.game.add.text(this.game.world.centerX, this.game.world.centerY, "Thank you.", Toffee.Data.thanks_style);
            }
            else {
                this.text = this.game.add.text(this.game.world.centerX, this.game.world.centerY, this.game.rnd.pick(Toffee.Data.cool), Toffee.Data.cool_style);
            }
            this.text.x = this.game.world.centerX - this.text.width / 2;
            this.addChild(this.rect);
            this.addChild(this.text);
            this.game.add.existing(this);
            this.alpha = 0;
            var tween = this.game.add.tween(this).to({ alpha: 1 }, 200);
            tween.onComplete.add(done ? this.nextMe : this.waitMe, this);
            tween.start();
        }
        Trans.prototype.waitMe = function () {
            this.playMe.appear();
            var tween = this.game.add.tween(this).to({ alpha: 0 }, 100);
            tween.delay(800);
            tween.onComplete.add(this.killMe, this);
            tween.start();
        };
        Trans.prototype.killMe = function () {
            this.rect.destroy();
            this.destroy();
        };
        Trans.prototype.nextMe = function () {
            this.toText("Never let someone choose who you are...", this.preEnding);
        };
        Trans.prototype.preEnding = function () {
            // no matter what
            this.toText("...no matter what...", this.ending);
        };
        Trans.prototype.ending = function () {
            // just be yourself
            this.toText("... be yourself.", null);
        };
        Trans.prototype.toText = function (mess, after) {
            var _this = this;
            var tween = this.game.add.tween(this.text).to({ alpha: 0 }, 100);
            tween.delay(3000);
            tween.onComplete.add(function () {
                _this.text.text = mess;
                _this.text.x = _this.game.world.centerX - _this.text.width / 2;
                var ano = _this.game.add.tween(_this.text).to({ alpha: 1 }, 100);
                ano.onComplete.add(function () {
                    if (after) {
                        after.call(_this);
                    }
                }, _this);
                ano.start();
            }, this);
            tween.start();
        };
        return Trans;
    })(Phaser.Sprite);
    Toffee.Trans = Trans;
})(Toffee || (Toffee = {}));
var Toffee;
(function (Toffee) {
    var Tuto = (function (_super) {
        __extends(Tuto, _super);
        function Tuto(game) {
            _super.call(this, game, 0, 0, "pointer");
            this.anchor.setTo(0.5);
            this.alpha = 0;
            this.game.add.existing(this);
        }
        // Info for drag in to the mold
        // TODO Another curve ?
        Tuto.prototype.dragIt = function () {
            var x = Toffee.Data.getWidth() / 2 + Toffee.Data.getWidth() / 4;
            this.fromTo(x, Toffee.Data.getWidth() / 4);
        };
        Tuto.prototype.fromTo = function (from, to) {
            var y = Toffee.Data.getHeight() / 2;
            this.position.setTo(from, y);
            this.tween = this.game.add.tween(this);
            this.tween.to({ alpha: 1 }, 200).to({ x: to }, 1000).to({ alpha: 0 }, 200).to({ x: from }, 1000);
            this.tween.loop();
            this.tween.start();
        };
        Tuto.prototype.stopIt = function () {
            this.tween.stop();
            this.alpha = 0;
        };
        // Info for dragging back
        Tuto.prototype.dragBack = function () {
            this.tween.stop();
            this.alpha = 0;
            var x = Toffee.Data.getWidth() / 2 + Toffee.Data.getWidth() / 4;
            this.fromTo(Toffee.Data.getWidth() / 4, x);
        };
        return Tuto;
    })(Phaser.Sprite);
    Toffee.Tuto = Tuto;
})(Toffee || (Toffee = {}));
var Toffee;
(function (Toffee) {
    var Wailings = (function (_super) {
        __extends(Wailings, _super);
        function Wailings(game) {
            _super.call(this, game);
        }
        Wailings.prototype.newOne = function () {
            var x = this.game.rnd.integerInRange(Toffee.Data.shapeX, Toffee.Data.shapeX + 300);
            var y = this.game.rnd.integerInRange(100, 400);
            var text = this.game.add.text(x, y, this.game.rnd.pick(Toffee.Data.wailings), Toffee.Data.wailing_style);
            this.game.add.tween(text).to({ alpha: 0 }, 1000).delay(2000).start();
        };
        return Wailings;
    })(Phaser.Group);
    Toffee.Wailings = Wailings;
})(Toffee || (Toffee = {}));
//# sourceMappingURL=app.js.map